==> AgeOn1.8.2_source.zip: AgeOn1.8.2_source/nispi/Controls/Menu/MainMenu/TabMenu/ThreadListTabMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Threading;
using System.Drawing;

using nispi.controlclass;

namespace nispi
{
    class ThreadListTabMainMenu
    {
        public ToolStripMenuItemParts menuItemCloseTabParts;
        public ToolStripMenuItemParts menuItemCloseAllTabParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemCreateNewThreadParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        public ToolStripMenuItemParts menuItemReloadParts;

        public ThreadListTabEvent threadListTabEvent;

        public ThreadListTabMainMenu(ToolStripMenuItemParts menuItem)
        {

            menuItemCloseTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCloseAllTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCreateNewThreadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();

            menuItemCloseTabParts.Text = "^u(&W)(CTRL+W)";

            menuItemCloseAllTabParts.Text = "ׂẴ^u(&Q)(CTRL+Q)";

            menuItemAddFavoriteParts.Text = "Cɓɒǉ(&F)(CTRL+F)";

            menuItemCreateNewThreadParts.Text = "Xbhɏ(&V)";

            menuItemOpenBrowserParts.Text = "uEU[ŊJ(&B)";

            menuItemCopyURLParts.Text = "URLRs[(&C)";

            menuItemCopyTitleParts.Text = "^CgRs[(&T)";

            menuItemReloadParts.Text = "ēǂݍ(&R)(CTRL+R)";

            menuItem.DropDownItemsAdd(menuItemCloseTabParts);
            menuItem.DropDownItemsAdd(menuItemCloseAllTabParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemCreateNewThreadParts);
            menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemReloadParts);

            threadListTabEvent = new ThreadListTabEvent(this);
        }
        public void SetupMainMenu()
        {
            int num = Const.form.threadListTabControlParts.SelectedIndex;
            if ((MainFormConst.threadListTabMain.viewList[num].datUrl != null) &&
                (MainFormConst.threadListTabMain.viewList[num].datUrl.Length > 0))
            {
                menuItemCloseTabParts.Enabled = true;
                menuItemCloseAllTabParts.Enabled = true;
                menuItemAddFavoriteParts.Enabled = true;
                menuItemCreateNewThreadParts.Enabled = true;
                menuItemOpenBrowserParts.Enabled = true;
                menuItemCopyURLParts.Enabled = true;
                menuItemCopyTitleParts.Enabled = true;
                menuItemReloadParts.Enabled = true;
            }
            else
            {
                menuItemCloseTabParts.Enabled = false;
                menuItemCloseAllTabParts.Enabled = false;
                menuItemAddFavoriteParts.Enabled = false;
                menuItemCreateNewThreadParts.Enabled = false;
                menuItemOpenBrowserParts.Enabled = false;
                menuItemCopyURLParts.Enabled = false;
                menuItemCopyTitleParts.Enabled = false;
                menuItemReloadParts.Enabled = false;
            }
        }
    }
}

==> AgeOn2.5_source.zip: AgeOn2.5_source/nispi/Controls/Menu/MainMenu/TabMenu/ThreadListTabMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Threading;
using System.Drawing;

using nispi.controlclass;

namespace nispi
{
    class ThreadListTabMainMenu
    {
        public ToolStripMenuItemParts menuItemCloseTabParts;
        public ToolStripMenuItemParts menuItemCloseAllTabParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemCreateNewThreadParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        public ToolStripMenuItemParts menuItemReloadParts;
        public ToolStripMenuItemParts menuItemRelationThreadParts;
        public ToolStripMenuItemParts menuItemOpenBBSParts;

        public ThreadListTabEvent threadListTabEvent;

        public ThreadListTabMainMenu(ToolStripMenuItemParts menuItem)
        {

            menuItemCloseTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCloseAllTabParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCreateNewThreadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemRelationThreadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBBSParts = ToolStripMenuItemPartsManager.Pop();

            menuItemCloseTabParts.Text = "^u(&W)(CTRL+W)";

            menuItemCloseAllTabParts.Text = "ׂẴ^u(&Q)(CTRL+Q)";

            menuItemAddFavoriteParts.Text = "Cɓɒǉ(&F)(CTRL+F)";

            menuItemCreateNewThreadParts.Text = "Xbhɏ(&V)";

            menuItemOpenBrowserParts.Text = "uEU[ŊJ(&B)";

            menuItemCopyURLParts.Text = "URLRs[(&C)";

            menuItemCopyTitleParts.Text = "^CgRs[(&T)";

            menuItemRelationThreadParts.Text = "֘AXbhT(&E)";

            menuItemOpenBBSParts.Text = "BBSJ(&X)";

            menuItemReloadParts.Text = "ēǂݍ(&R)(CTRL+R)";

            menuItem.DropDownItemsAdd(menuItemCloseTabParts);
            menuItem.DropDownItemsAdd(menuItemCloseAllTabParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemCreateNewThreadParts);
            menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            menuItem.DropDownItemsAdd(menuItemRelationThreadParts);
            menuItem.DropDownItemsAdd(menuItemOpenBBSParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemReloadParts);

            threadListTabEvent = new ThreadListTabEvent(this);
        }
        public void SetupMainMenu()
        {
            int num = Const.form.threadListTabControlParts.SelectedIndex;
            if ((MainFormConst.threadListTabMain.viewList[num].datUrl != null) &&
                (MainFormConst.threadListTabMain.viewList[num].datUrl.Length > 0))
            {
                menuItemCloseTabParts.Enabled = true;
                menuItemCloseAllTabParts.Enabled = true;
                menuItemAddFavoriteParts.Enabled = true;
                menuItemCreateNewThreadParts.Enabled = true;
                menuItemOpenBrowserParts.Enabled = true;
                menuItemCopyURLParts.Enabled = true;
                menuItemCopyTitleParts.Enabled = true;
                menuItemRelationThreadParts.Enabled = true;
                menuItemReloadParts.Enabled = true;
                menuItemOpenBBSParts.Enabled = true;
            }
            else
            {
                menuItemCloseTabParts.Enabled = false;
                menuItemCloseAllTabParts.Enabled = false;
                menuItemAddFavoriteParts.Enabled = false;
                menuItemCreateNewThreadParts.Enabled = false;
                menuItemOpenBrowserParts.Enabled = false;
                menuItemCopyURLParts.Enabled = false;
                menuItemCopyTitleParts.Enabled = false;
                menuItemRelationThreadParts.Enabled = false;
                menuItemReloadParts.Enabled = false;
                menuItemOpenBBSParts.Enabled = false;
            }
        }
    }
}
